@@ -5,7 +5,7 @@
 #include <inttypes.h>
 #include <stdio.h>
 
-int main()
+int main(void)
 {
   uint64_t count = primesieve_count_primes(0, 1000);
   printf("Primes <= 1000: %" PRIu64 "\n", count);
