@@ -11,7 +11,8 @@
 ///         fillNextPrimes() is highly optimized using hardware
 ///         acceleration (e.g. CTZ, AVX512) whenever possible.
 ///
-/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2023 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2022 @zielaj, https://github.com/zielaj
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -26,7 +27,7 @@
 #include <primesieve/primesieve_error.hpp>
 #include <primesieve/macros.hpp>
 #include <primesieve/pmath.hpp>
-#include <primesieve/pod_vector.hpp>
+#include <primesieve/Vector.hpp>
 #include <primesieve/intrinsics.hpp>
 #include <primesieve/SievingPrimes.hpp>
 
@@ -41,7 +42,7 @@
 namespace {
 
 /// First 128 primes
-const primesieve::pod_array<uint64_t, 128> smallPrimes =
+const primesieve::Array<uint64_t, 128> smallPrimes =
 {
     2,   3,   5,   7,  11,  13,  17,  19,  23,  29,
    31,  37,  41,  43,  47,  53,  59,  61,  67,  71,
@@ -59,7 +60,7 @@ const primesieve::pod_array<uint64_t, 128> smallPrimes =
 };
 
 /// Number of primes <= n
-const primesieve::pod_array<uint8_t, 720> primePi =
+const primesieve::Array<uint8_t, 720> primePi =
 {
     0,   0,   1,   2,   2,   3,   3,   4,   4,   4,   4,   5,   5,   6,   6,
     6,   6,   7,   7,   8,   8,   8,   8,   9,   9,   9,   9,   9,   9,  10,
@@ -150,10 +151,10 @@ std::size_t PrimeGenerator::getStopIdx() const
 }
 
 /// Used by iterator::prev_prime()
-void PrimeGenerator::initPrevPrimes(pod_vector<uint64_t>& primes,
+void PrimeGenerator::initPrevPrimes(Vector<uint64_t>& primes,
                                     std::size_t* size)
 {
-  auto resize = [](pod_vector<uint64_t>& primes,
+  auto resize = [](Vector<uint64_t>& primes,
                    std::size_t size)
   {
     // Avoids reallocation in fillPrevPrimes()
@@ -164,7 +165,7 @@ void PrimeGenerator::initPrevPrimes(pod_vector<uint64_t>& primes,
     // When sieving backwards the number of primes inside [start, stop]
     // slowly increases in each new segment as there are more small
     // than large primes. Our new size has been calculated using
-    // primeCountApprox(start, stop) which is usually too large by 4%
+    // primeCountUpper(start, stop) which is usually too large by 4%
     // near 10^12 and by 2.5% near 10^19. Hence if the new size is less
     // than 1% larger than the old size we do not increase the primes
     // buffer as it will likely be large enough to fit all primes.
@@ -177,7 +178,7 @@ void PrimeGenerator::initPrevPrimes(pod_vector<uint64_t>& primes,
     }
   };
 
-  std::size_t pix = primeCountApprox(start_, stop_);
+  std::size_t pix = primeCountUpper(start_, stop_);
 
   if (start_ <= maxCachedPrime())
   {
@@ -203,10 +204,10 @@ void PrimeGenerator::initPrevPrimes(pod_vector<uint64_t>& primes,
 }
 
 /// Used by iterator::next_prime()
-void PrimeGenerator::initNextPrimes(pod_vector<uint64_t>& primes,
+void PrimeGenerator::initNextPrimes(Vector<uint64_t>& primes,
                                     std::size_t* size)
 {
-  auto resize = [](pod_vector<uint64_t>& primes,
+  auto resize = [](Vector<uint64_t>& primes,
                    std::size_t size)
   {
     if (size > primes.size())
@@ -235,7 +236,7 @@ void PrimeGenerator::initNextPrimes(pod_vector<uint64_t>& primes,
       // algorithm aborts as soon as there is not
       // enough space to store 64 more primes.
       std::size_t minSize = *size + 64;
-      std::size_t pix = primeCountApprox(start_, stop_) + 64;
+      std::size_t pix = primeCountUpper(start_, stop_) + 64;
       pix = inBetween(minSize, pix, maxSize);
       pix = std::max(*size, pix);
       resize(primes, pix);
@@ -252,7 +253,7 @@ void PrimeGenerator::initNextPrimes(pod_vector<uint64_t>& primes,
     // algorithm aborts as soon as there is not
     // enough space to store 64 more primes.
     std::size_t minSize = 64;
-    std::size_t pix = primeCountApprox(start_, stop_) + 64;
+    std::size_t pix = primeCountUpper(start_, stop_) + 64;
     pix = inBetween(minSize, pix, maxSize);
     resize(primes, pix);
   }
@@ -297,7 +298,7 @@ void PrimeGenerator::sieveSegment()
 }
 
 /// Used by iterator::prev_prime()
-bool PrimeGenerator::sievePrevPrimes(pod_vector<uint64_t>& primes,
+bool PrimeGenerator::sievePrevPrimes(Vector<uint64_t>& primes,
                                      std::size_t* size)
 {
   if (!isInit_)
@@ -316,7 +317,7 @@ bool PrimeGenerator::sievePrevPrimes(pod_vector<uint64_t>& primes,
 }
 
 /// Used by iterator::next_prime()
-bool PrimeGenerator::sieveNextPrimes(pod_vector<uint64_t>& primes,
+bool PrimeGenerator::sieveNextPrimes(Vector<uint64_t>& primes,
                                      std::size_t* size)
 {
   if (!isInit_)
@@ -345,7 +346,7 @@ bool PrimeGenerator::sieveNextPrimes(pod_vector<uint64_t>& primes,
 /// over the primes inside [a, b] we need to generate new
 /// primes which incurs an initialization overhead of O(sqrt(n)).
 ///
-void PrimeGenerator::fillPrevPrimes(pod_vector<uint64_t>& primes,
+void PrimeGenerator::fillPrevPrimes(Vector<uint64_t>& primes,
                                     std::size_t* size)
 {
   *size = 0;
@@ -402,7 +403,7 @@ void PrimeGenerator::fillPrevPrimes(pod_vector<uint64_t>& primes,
 #if defined(MULTIARCH)
   __attribute__ ((target ("default")))
 #endif
-void PrimeGenerator::fillNextPrimes(pod_vector<uint64_t>& primes,
+void PrimeGenerator::fillNextPrimes(Vector<uint64_t>& primes,
                                     std::size_t* size)
 {
   *size = 0;
@@ -463,7 +464,7 @@ void PrimeGenerator::fillNextPrimes(pod_vector<uint64_t>& primes,
 /// have been enabled which should provide up to 10% speedup.
 ///
 __attribute__ ((target ("popcnt,bmi")))
-void PrimeGenerator::fillNextPrimes(pod_vector<uint64_t>& primes,
+void PrimeGenerator::fillNextPrimes(Vector<uint64_t>& primes,
                                     std::size_t* size)
 {
   *size = 0;
@@ -535,7 +536,7 @@ void PrimeGenerator::fillNextPrimes(pod_vector<uint64_t>& primes,
 /// fillNextPrimes() algorithm which uses __builtin_ctzll().
 ///
 __attribute__ ((target ("avx512f,avx512vbmi,avx512vbmi2,popcnt")))
-void PrimeGenerator::fillNextPrimes(pod_vector<uint64_t>& primes,
+void PrimeGenerator::fillNextPrimes(Vector<uint64_t>& primes,
                                     std::size_t* size)
 {
   *size = 0;
