@@ -13,6 +13,7 @@
 #include <stdint.h>
 #include <iostream>
 #include <cstdlib>
+#include <string>
 #include <vector>
 
 using namespace primesieve;
@@ -83,6 +84,21 @@ int main()
     check(primes[i] == large_primes[i]);
   }
 
+  std::string errorMsg;
+
+  try
+  {
+    std::vector<uint16_t> primes16;
+    generate_n_primes(10, (1 << 16) - 10, &primes16);
+  }
+  catch (const primesieve_error& e)
+  {
+    errorMsg = e.what();
+  }
+
+  std::cout << "Detect 16-bit overflow: " << errorMsg;
+  check(!errorMsg.empty());
+
   std::cout << std::endl;
   std::cout << "All tests passed successfully!" << std::endl;
 
