@@ -2,7 +2,7 @@
 /// @file   nth_prime1.cpp
 /// @brief  Test nth_prime for |n| <= 9592
 ///
-/// Copyright (C) 2017 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -15,20 +15,19 @@
 #include <vector>
 #include <cstdlib>
 
-using namespace std;
 using namespace primesieve;
 
 void check(bool OK)
 {
-  cout << "   " << (OK ? "OK" : "ERROR") << "\n";
+  std::cout << "   " << (OK ? "OK" : "ERROR") << "\n";
   if (!OK)
-    exit(1);
+    std::exit(1);
 }
 
 int main()
 {
   uint64_t upperBound = (uint64_t) 1e5;
-  vector<uint64_t> primes;
+  std::vector<uint64_t> primes;
   generate_primes(upperBound, &primes);
   int64_t i = primes.size() - 1;
   int64_t n = 0;
@@ -38,7 +37,7 @@ int main()
   {
     n++;
     uint64_t res = nth_prime(n);
-    cout << "nth_prime(" << n << ") = " << res;
+    std::cout << "nth_prime(" << n << ") = " << res;
     check(res == prime);
   }
 
@@ -47,12 +46,12 @@ int main()
   {
     n--;
     uint64_t res = nth_prime(n, upperBound);
-    cout << "nth_prime(" << n << ", " << upperBound << ") = " << res;
+    std::cout << "nth_prime(" << n << ", " << upperBound << ") = " << res;
     check(res == primes[i]);
   }
 
-  cout << endl;
-  cout << "All tests passed successfully!" << endl;
+  std::cout << std::endl;
+  std::cout << "All tests passed successfully!" << std::endl;
 
   return 0;
 }
