@@ -2,7 +2,7 @@
 /// @file   nth_prime3.cpp
 /// @brief  Long distance nth prime testing.
 ///
-/// Copyright (C) 2017 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2022 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -14,7 +14,6 @@
 #include <iostream>
 #include <cstdlib>
 
-using namespace std;
 using namespace primesieve;
 
 void nth_prime_test(int64_t n, int64_t start, int64_t iters)
@@ -28,9 +27,9 @@ void nth_prime_test(int64_t n, int64_t start, int64_t iters)
 
     if (i_start <= smaller || i_start > larger)
     {
-      cerr << endl;
-      cerr << "nth_prime(" << -n << ", " << i_start << ") = " << prime << "   ERROR" << endl;
-      exit(1);
+      std::cerr << std::endl;
+      std::cerr << "nth_prime(" << -n << ", " << i_start << ") = " << prime << "   ERROR" << std::endl;
+      std::exit(1);
     }
   }
 }
@@ -45,18 +44,18 @@ int main()
   {
     for (int j = 8; j <= 10; j++)
     {
-      int64_t n = (int64_t) pow(10.0, i);
-      int64_t start = (int64_t) pow(10.0, j);
+      int64_t n = (int64_t) std::pow(10.0, i);
+      int64_t start = (int64_t) std::pow(10.0, j);
       int64_t iters = 5;
 
-      cout << "nth_prime_test(" << n << ", " << start << ", " << iters << ")";
+      std::cout << "nth_prime_test(" << n << ", " << start << ", " << iters << ")";
       nth_prime_test(n, start, iters);
-      cout << " = OK" << endl;
+      std::cout << " = OK" << std::endl;
     }
   }
 
-  cout << endl;
-  cout << "All tests passed successfully!" << endl;
+  std::cout << std::endl;
+  std::cout << "All tests passed successfully!" << std::endl;
 
   return 0;
 }
